/**
 * Gets the value of an argument.
 *
 * ---
 *
 * CLI arguments examples:
 *
 * ```sh
 * command --arg=some # 'some'
 * command --arg=""   # ''
 * command --arg      # undefined
 * ```
 */
export declare const getArg: (arg: string, prefix?: string) => string | undefined;
/**
 * Parses all arguments of an argument value.
 *
 * ---
 *
 * CLI arguments examples:
 *
 * ```sh
 * command --arg='--sub=some'         # ['--sub=some']
 * command --arg='--sub=some, --sub2' # ['--sub=some', '--sub2']
 * ```
 */
export declare const getSubArg: (arg: string, prefix?: string) => string[] | undefined;
/**
 * Checks if an argument exists.
 *
 * ---
 *
 * CLI arguments examples:
 *
 * ```sh
 * command --arg  # true
 * command        # false
 * ```
 */
export declare const hasArg: (arg: string, prefix?: string) => boolean;
/**
 * Gets the last param/value.
 *
 * CLI arguments examples:
 *
 * ```sh
 * command --arg --arg2=some value  # 'value'
 * command value                    # 'value'
 * command                          # undefined
 * command --arg                    # undefined
 * ```
 */
export declare const getLastParam: (prefix?: string) => string | undefined;
