"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLastParam = exports.hasArg = exports.getSubArg = exports.getArg = void 0;
/* c8 ignore start */
const node_process_1 = __importDefault(require("process"));
const [, , ...processArgs] = node_process_1.default.argv;
/**
 * Gets the value of an argument.
 *
 * ---
 *
 * CLI arguments examples:
 *
 * ```sh
 * command --arg=some # 'some'
 * command --arg=""   # ''
 * command --arg      # undefined
 * ```
 */
const getArg = (arg, prefix = '--') => {
    var _a;
    const mountArg = processArgs.find((a) => a.startsWith(`${prefix}${arg}=`));
    if (!mountArg)
        return undefined;
    return (_a = mountArg.split('=')) === null || _a === void 0 ? void 0 : _a[1].replace(/''|""/, '');
};
exports.getArg = getArg;
/**
 * Parses all arguments of an argument value.
 *
 * ---
 *
 * CLI arguments examples:
 *
 * ```sh
 * command --arg='--sub=some'         # ['--sub=some']
 * command --arg='--sub=some, --sub2' # ['--sub=some', '--sub2']
 * ```
 */
const getSubArg = (arg, prefix = '--') => {
    var _a, _b;
    if ((0, exports.hasArg)(arg) && !((_a = (0, exports.getArg)(arg)) === null || _a === void 0 ? void 0 : _a[1]))
        return [];
    return (_b = processArgs
        .find((a) => a.startsWith(`${prefix}${arg}=`))) === null || _b === void 0 ? void 0 : _b.split(`--${arg}=`)[1].split(',').map((a) => a.trim()).filter((a) => a && !/''|""/.test(a));
};
exports.getSubArg = getSubArg;
/**
 * Checks if an argument exists.
 *
 * ---
 *
 * CLI arguments examples:
 *
 * ```sh
 * command --arg  # true
 * command        # false
 * ```
 */
const hasArg = (arg, prefix = '--') => processArgs.some((a) => a.startsWith(`${prefix}${arg}`));
exports.hasArg = hasArg;
/**
 * Gets the last param/value.
 *
 * CLI arguments examples:
 *
 * ```sh
 * command --arg --arg2=some value  # 'value'
 * command value                    # 'value'
 * command                          # undefined
 * command --arg                    # undefined
 * ```
 */
const getLastParam = (prefix = '--') => {
    const lastArg = processArgs[processArgs.length - 1];
    if (!lastArg || lastArg.startsWith(prefix))
        return undefined;
    return lastArg;
};
exports.getLastParam = getLastParam;
// TODO (Custom Args)
// export const getAllArgs = (arg: string, prefix = '--'): string[] => {
//   return processArgs
//     .filter((a) => a.startsWith(`${prefix}${arg}=`) || a === `${prefix}${arg}`)
//     .map((a) => {
//       const [key, ...value] = a.split('=');
//       return value.length > 0 ? value.join('=') : key;
//     });
// };
// TODO (Custom Args)
// export const setArgs = (
//   args: (string | Record<string, string>)[],
//   options?: { prefix: string }
// ): string[] => {
//   const customArgs: string[] = [];
//   const prefix = options?.prefix || '';
//   args.forEach((arg) => {
//     if (!Array.isArray(arg) && typeof arg === 'object') {
//       for (const key in arg) {
//         customArgs.push(`${prefix}${key}=${arg[key]}`);
//       }
//       return;
//     }
//     customArgs.push(`${prefix}${arg}`);
//   });
//   return customArgs;
// };
/* c8 ignore stop */
