"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.publicListFiles = exports.listFiles = exports.isDir = exports.isFile = exports.escapeRegExp = exports.sanitizePath = void 0;
const node_process_1 = __importDefault(require("process"));
const node_fs_1 = __importDefault(require("fs"));
const node_path_1 = __importDefault(require("path"));
const sanitizePath = (input, ensureTarget) => {
    const sanitizedPath = input
        .replace(/[/\\]+/g, node_path_1.default.sep) // adapting slashes according to OS
        .replace(/(\.\.(\/|\\|$))+/g, '') // ensure the current path level
        .replace(/[<>|^?*]+/g, ''); // removing unusual path characters
    // Preventing absolute path access
    return ensureTarget ? sanitizedPath.replace(/^[/\\]/, './') : sanitizedPath;
};
exports.sanitizePath = sanitizePath;
const escapeRegExp = (string) => string.replace(/[.*{}[\]\\]/g, '\\$&');
exports.escapeRegExp = escapeRegExp;
const isFile = (fullPath) => node_fs_1.default.statSync(fullPath).isFile();
exports.isFile = isFile;
const isDir = (fullPath) => node_fs_1.default.statSync(fullPath).isDirectory();
exports.isDir = isDir;
const envFilter = ((_a = node_process_1.default.env.FILTER) === null || _a === void 0 ? void 0 : _a.trim())
    ? new RegExp((0, exports.escapeRegExp)(node_process_1.default.env.FILTER), 'i')
    : null;
const listFiles = (dirPath, files = [], configs) => {
    const currentFiles = node_fs_1.default.readdirSync((0, exports.sanitizePath)(dirPath));
    const defaultRegExp = /\.(test|spec)\./i;
    const filter = (envFilter
        ? envFilter
        : (configs === null || configs === void 0 ? void 0 : configs.filter) instanceof RegExp
            ? configs.filter
            : defaultRegExp) || defaultRegExp;
    const exclude = (configs === null || configs === void 0 ? void 0 : configs.exclude)
        ? Array.isArray(configs.exclude)
            ? configs.exclude
            : [configs.exclude]
        : undefined;
    for (const file of currentFiles) {
        const fullPath = (0, exports.sanitizePath)(node_path_1.default.join(dirPath, file));
        if (/node_modules/.test(fullPath))
            continue;
        if (exclude && exclude.some((regex) => regex.test(fullPath)))
            continue;
        if ((0, exports.isDir)(fullPath))
            (0, exports.listFiles)(fullPath, files, configs);
        else if (filter.test(fullPath))
            files.push(fullPath);
    }
    return files;
};
exports.listFiles = listFiles;
const publicListFiles = (targetDir, configs) => (0, exports.listFiles)((0, exports.sanitizePath)(targetDir), [], configs);
exports.publicListFiles = publicListFiles;
