"use strict";
/* c8 ignore start */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.poku = void 0;
/**
 * Both CLI, API, noExit, sequential and parallel runs are strictly tested, but these tests use deep child process for it
 */
const node_os_1 = require("os");
const force_array_js_1 = require("../helpers/force-array.js");
const run_tests_js_1 = require("../services/run-tests.js");
const exit_js_1 = require("./exit.js");
const format_js_1 = require("../helpers/format.js");
const logs_js_1 = require("../helpers/logs.js");
const hr_js_1 = require("../helpers/hr.js");
const files_js_1 = require("../configs/files.js");
const indentation_js_1 = require("../configs/indentation.js");
function poku(targetPaths, configs) {
    return __awaiter(this, void 0, void 0, function* () {
        let code = 0;
        const prepareDirs = (0, force_array_js_1.forceArray)(targetPaths);
        const dirs = prepareDirs.length > 0 ? prepareDirs : ['./'];
        const showLogs = !(0, logs_js_1.isQuiet)(configs);
        // Sequential
        if (!(configs === null || configs === void 0 ? void 0 : configs.parallel)) {
            for (const dir of dirs) {
                const result = yield (0, run_tests_js_1.runTests)(dir, configs);
                if (!result) {
                    code = 1;
                    if (configs === null || configs === void 0 ? void 0 : configs.failFast)
                        break;
                }
            }
            if (configs === null || configs === void 0 ? void 0 : configs.noExit)
                return code;
            (0, exit_js_1.exit)(code, configs === null || configs === void 0 ? void 0 : configs.quiet);
            return;
        }
        // Parallel
        if (showLogs) {
            (0, hr_js_1.hr)();
            console.log(`${format_js_1.format.bold('Running the Test Suite in Parallel')}${node_os_1.EOL}`);
        }
        try {
            const promises = dirs.map((dir) => __awaiter(this, void 0, void 0, function* () {
                const result = yield (0, run_tests_js_1.runTestsParallel)(dir, configs);
                if (!result && (configs === null || configs === void 0 ? void 0 : configs.failFast))
                    throw '';
                return result;
            }));
            const concurrency = yield Promise.all(promises);
            if (concurrency.some((result) => !result))
                code = 1;
        }
        catch (_a) { }
        showLogs && (0, hr_js_1.hr)();
        if (showLogs && files_js_1.fileResults.success.length > 0)
            console.log(files_js_1.fileResults.success
                .map((current) => `${indentation_js_1.indentation.test}${format_js_1.format.success('✔')} ${format_js_1.format.dim(current)}`)
                .join(node_os_1.EOL));
        if (showLogs && files_js_1.fileResults.fail.length > 0)
            console.log(files_js_1.fileResults.fail
                .map((current) => `${indentation_js_1.indentation.test}${format_js_1.format.fail('✘')} ${current}`)
                .join(node_os_1.EOL));
        if (configs === null || configs === void 0 ? void 0 : configs.noExit)
            return code;
        (0, exit_js_1.exit)(code, configs === null || configs === void 0 ? void 0 : configs.quiet);
    });
}
exports.poku = poku;
/* c8 ignore stop */
