"use strict";
/* c8 ignore start */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.kill = exports.getPIDs = void 0;
const runner_js_1 = require("../helpers/runner.js");
const pid_js_1 = require("../services/pid.js");
const getPIDsByPorts = (port) => __awaiter(void 0, void 0, void 0, function* () {
    const ports = (0, pid_js_1.setPortsAndPIDs)(port);
    const PIDs = [];
    yield Promise.all(ports.map((p) => __awaiter(void 0, void 0, void 0, function* () {
        PIDs.push(...(yield (runner_js_1.isWindows
            ? pid_js_1.getPIDs.windows(p)
            : pid_js_1.getPIDs.unix(p))));
    })));
    return PIDs;
});
const getPIDsByRange = (startsAt, endsAt) => __awaiter(void 0, void 0, void 0, function* () {
    const ports = (0, pid_js_1.populateRange)(startsAt, endsAt);
    return yield (0, exports.getPIDs)(ports);
});
/**
 * Returns an array containing the ID of all processes listening to the specified port
 */
exports.getPIDs = Object.assign(getPIDsByPorts, {
    /**
     * Returns an array containing the ID of all processes listening to the specified range port
     */
    range: getPIDsByRange,
});
const killPID = (PID) => __awaiter(void 0, void 0, void 0, function* () {
    const PIDs = (0, pid_js_1.setPortsAndPIDs)(PID);
    yield Promise.all(PIDs.map((p) => __awaiter(void 0, void 0, void 0, function* () {
        runner_js_1.isWindows
            ? yield pid_js_1.killPID.windows(p)
            : yield pid_js_1.killPID.unix(p);
    })));
});
const killPort = (port) => __awaiter(void 0, void 0, void 0, function* () {
    const PIDs = yield (0, exports.getPIDs)(port);
    for (const PID of PIDs) {
        if (!PID)
            continue;
        yield killPID(PID);
    }
});
const killRange = (startsAt, endsAt) => __awaiter(void 0, void 0, void 0, function* () {
    const PIDs = yield exports.getPIDs.range(startsAt, endsAt);
    for (const PID of PIDs) {
        if (!PID)
            continue;
        yield killPID(PID);
    }
});
exports.kill = {
    /**
     * Terminates the specified process ID
     */
    pid: killPID,
    /**
     * Terminates all processes listening on the specified port
     */
    port: killPort,
    /**
     * Terminates all processes listening on the specified range ports
     */
    range: killRange,
};
/* c8 ignore stop */
