"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runTestsParallel = exports.runTests = exports.results = void 0;
const node_process_1 = __importDefault(require("process"));
const node_os_1 = require("os");
const node_path_1 = __importDefault(require("path"));
const runner_js_1 = require("../helpers/runner.js");
const indentation_js_1 = require("../configs/indentation.js");
const list_files_js_1 = require("../modules/list-files.js");
const hr_js_1 = require("../helpers/hr.js");
const format_js_1 = require("../helpers/format.js");
const run_test_file_js_1 = require("./run-test-file.js");
const logs_js_1 = require("../helpers/logs.js");
/* c8 ignore start */
exports.results = {
    success: 0,
    fail: 0,
};
/* c8 ignore stop */
const runTests = (dir, configs) => __awaiter(void 0, void 0, void 0, function* () {
    const cwd = node_process_1.default.cwd();
    const testDir = node_path_1.default.join(cwd, (0, list_files_js_1.sanitizePath)(dir));
    const currentDir = node_path_1.default.relative(cwd, testDir);
    const isFile = (0, list_files_js_1.isFile)(testDir);
    const files = isFile ? [testDir] : (0, list_files_js_1.listFiles)(testDir, undefined, configs);
    const totalTests = files.length;
    const showLogs = !(0, logs_js_1.isQuiet)(configs);
    let passed = true;
    if (showLogs) {
        (0, hr_js_1.hr)();
        console.log(`${format_js_1.format.bold(isFile ? 'File:' : 'Directory:')} ${format_js_1.format.underline(`./${currentDir}`)}${node_os_1.EOL}`);
    }
    for (let i = 0; i < files.length; i++) {
        const filePath = files[i];
        const fileRelative = node_path_1.default.relative(cwd, filePath);
        const testPassed = yield (0, run_test_file_js_1.runTestFile)(filePath, configs);
        const testNumber = i + 1;
        const counter = format_js_1.format.counter(testNumber, totalTests);
        const command = `${(0, runner_js_1.runner)(fileRelative, configs).join(' ')} ${fileRelative}`;
        const nextLine = i + 1 !== files.length ? node_os_1.EOL : '';
        const log = `${counter}/${totalTests} ${command}`;
        if (testPassed) {
            ++exports.results.success;
            showLogs &&
                console.log(`${indentation_js_1.indentation.test}${format_js_1.format.success('✔')} ${log}`, nextLine);
        }
        else {
            ++exports.results.fail;
            showLogs &&
                console.log(`${indentation_js_1.indentation.test}${format_js_1.format.fail('✘')} ${log}`, nextLine);
            passed = false;
            if (configs === null || configs === void 0 ? void 0 : configs.failFast) {
                (0, hr_js_1.hr)();
                console.log(`  ${format_js_1.format.fail('ℹ')} ${format_js_1.format.bold('fail-fast')} is enabled`);
                break;
            }
        }
    }
    return passed;
});
exports.runTests = runTests;
const runTestsParallel = (dir, configs) => __awaiter(void 0, void 0, void 0, function* () {
    const cwd = node_process_1.default.cwd();
    const testDir = node_path_1.default.join(cwd, dir);
    const files = (0, list_files_js_1.isFile)(dir) ? [dir] : (0, list_files_js_1.listFiles)(testDir, undefined, configs);
    const filesByConcurrency = [];
    const concurrencyLimit = (configs === null || configs === void 0 ? void 0 : configs.concurrency) || 0;
    const concurrencyResults = [];
    if (concurrencyLimit > 0)
        for (let i = 0; i < files.length; i += concurrencyLimit) {
            filesByConcurrency.push(files.slice(i, i + concurrencyLimit));
        }
    else
        filesByConcurrency.push(files);
    try {
        for (const fileGroup of filesByConcurrency) {
            const promises = fileGroup.map((filePath) => __awaiter(void 0, void 0, void 0, function* () {
                if ((configs === null || configs === void 0 ? void 0 : configs.failFast) && exports.results.fail > 0)
                    return;
                const testPassed = yield (0, run_test_file_js_1.runTestFile)(filePath, configs);
                if (!testPassed) {
                    ++exports.results.fail;
                    if (configs === null || configs === void 0 ? void 0 : configs.failFast)
                        throw `  ${format_js_1.format.fail('ℹ')} ${format_js_1.format.bold('fail-fast')} is enabled`;
                    return false;
                }
                ++exports.results.success;
                return true;
            }));
            const concurrency = yield Promise.all(promises);
            concurrencyResults.push(concurrency);
        }
        return concurrencyResults.every((group) => group.every((result) => result));
    }
    catch (error) {
        (0, hr_js_1.hr)();
        console.log(error);
        return false;
    }
});
exports.runTestsParallel = runTestsParallel;
